# کدال و بورس در پایتون

این پکیچ برای جستجوی داده‌های سایت کدال و بازار سرمایه برای اهداف تحلیل بنیادی تهیه شده است.

- [آموزش بسته](https://mohsenebrahimyir.github.io/codal-tsetmc/)
- [تلگرام @codal_tsetmc_package](https://t.me/codal_tsetmc_package)

برای ذخیره سازی داده‌های صورت مالی کدال پکیج دیگری در نظر گرفته شده که میتوانید با این ایمیل ارتباط بگیرید.

-(mohsenebrahimy.ir@gmail.com)<mailto:mohsenebrahimy.ir@gmail.com>

## نصب پکیج

نسخه‌های مجاز پایتون از 3.12 بالاتر باید باشد.

برای استفاده از این بسته پیشنهاد می‌شود از محیط مجازی استفاده کنید.

```bash
python -m venv .venv
```

فعال سازی محیط مجازی در لینوکس

```bash
source .venv/bin/activate
```

فعال سازی محیط مجازی در ویندوز

```cmd
> .\venv\Scripts\activate
```

نصب از `pypi`:

```bash
pip install -U codal-tsetmc
```

نصب از نسخه در حال توسعه `github`

```bash
pip install git+https://github.com/mohsenebrahimyir/codal-tsetmc.git
```
